@@ -2,6 +2,7 @@ from bs4 import BeautifulSoup
 from .Topic import *
 from .Core.List import *
 from .Core.Terminal import *
+from .href import href
 
 BS4_FEATURES = "lxml"
 
@@ -62,7 +63,9 @@ class Scraper:
         """
         Returns a list of links
         """
-        return List(str).extend([str(a['href']) for a in self._soup.find_all('a', href = True)])
+        hrefList = List(href)
+        hrefList.extend([href(a['href'], self.origin) for a in self._soup.find_all('a', href = True)])
+        return hrefList
 
     def __str__(self):
         return f"""
